//
//  ResaISkaneAppDelegate.m
//  ResaISkane
//
//  Copyright 2009-2010 Fredrik Olsson. All rights reserved.
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//  http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
//

#import "ResaISkaneAppDelegate.h"
#import "CWModel.h"
#import "CWPoint.h"
#import "CWJourney.h"
#import "CWJourneySearchController.h"
#import "CWJourneyListController.h"
#import "CWNetworkChecker.h"
#import "CWTranslatedString.h"

@implementation ResaISkaneAppDelegate

@synthesize window;

-(void)displayInformationIfNeeded;
{
	NSAutoreleasePool* pool = [[NSAutoreleasePool alloc] init];
  if ([CWNetworkChecker isNetworkAvailable]) {
    NSUserDefaults* defaults = [NSUserDefaults standardUserDefaults];
		NSArray* infoItems = [NSArray arrayWithContentsOfURL:[NSURL URLWithString:[[[NSBundle mainBundle] infoDictionary] valueForKey:@"InfoURL"]]];
    for (NSDictionary* infoItem in infoItems) {
			NSString* itemId = [infoItem objectForKey:@"id"];
      if ([defaults boolForKey:itemId] == NO) {
				UIAlertView* alert = [[UIAlertView alloc] initWithTitle:CWTranslatedString([infoItem objectForKey:@"title"], @"sv") message:[infoItem objectForKey:@"message"] delegate:nil cancelButtonTitle:NSLocalizedString(@"OK", nil) otherButtonTitles:nil];
        [alert performSelectorOnMainThread:@selector(show) withObject:nil waitUntilDone:YES];
        [alert release];
        [defaults setBool:YES forKey:itemId];
      }
    }
    [defaults synchronize];
  }
  [pool release];
}

- (void)applicationDidFinishLaunching:(UIApplication *)application {

	[CWNetworkChecker setDefaultHost:[[NSURL URLWithString:[[[NSBundle mainBundle] infoDictionary] valueForKey:@"ServerURL"]] host]];

  CWJourneySearchController* rootController = [[CWJourneySearchController alloc] init];
  mainViewController = [[UINavigationController alloc] initWithRootViewController:rootController];
	[rootController release];

  window.backgroundColor = [UIColor groupTableViewBackgroundColor];
  [window addSubview:mainViewController.view];
  [window makeKeyAndVisible];

  if ([CWModel sharedModel].currentJourneyList != nil) {
  	UIViewController* controller = [[CWJourneyListController alloc] init];
    [rootController presentModalViewController:controller animated:NO];
    [controller release];
  }
  UIImage* backImage = [UIImage imageNamed:@"Default.png"];
  UIView* backView = [[UIImageView alloc] initWithImage:backImage];
  backView.frame = window.bounds;
  [window addSubview:backView];
  [UIView beginAnimations:@"CWFadeIn" context:(void*)backView];
  [UIView setAnimationDelegate:self];
  [UIView setAnimationDidStopSelector:
   @selector(animationDidStop:finished:context:)];
  [UIView setAnimationDuration:0.5f];
  backView.alpha = 0;
  [UIView commitAnimations];
  [self performSelectorInBackground:@selector(displayInformationIfNeeded) withObject:nil];
}

-(void)animationDidStop:(NSString*)animationID finished:(NSNumber*)finished context:(void*)context
{
  UIView* backView = (UIView*)context;
  [backView removeFromSuperview];
  [backView release];
}

-(void)applicationWillTerminate:(UIApplication *)application;
{
	[[CWModel sharedModel] persistToStorage];
}

- (void)dealloc {
    [window release];
    [super dealloc];
}


@end
